# ml.neuralnetworks package

## Submodules

## ml.neuralnetworks.keras module

The keras module provides additions to work and visualize Keras neural networks


### ml.neuralnetworks.keras.enable_gpu()
Enables Keras to run on the GPU
First it checks if there’s a “physical device” available of type GPU
If not, it will try to leverage plaidml for GPU enabling


* **Returns**

    A boolean value indicating if the GPU enablement succeeded



* **Return type**

    bool


## Module contents
